FreeStor: A python library to interact with FalconStor FreeStor REST API
========

Modules were based in the Rest API calls described on "Freestor Rest API Developer Guide" document dated of 05-27-2016.


Dependencies
------------

 * python-requests

